@@ -1,6 +1,5 @@
 import array
 import copy
-import sys
 import xml.etree.ElementTree as ET
 from xml.dom import minidom
 
@@ -8,14 +7,14 @@ import numpy as np
 from PyQt5.QtCore import QObject, pyqtSignal, Qt
 
 from urh import constants
-from urh.awre.FormatFinder import FormatFinder
-from urh.cythonext import signal_functions, util
+from urh.cythonext import signal_functions
 from urh.signalprocessing.Encoding import Encoding
 from urh.signalprocessing.FieldType import FieldType
 from urh.signalprocessing.Message import Message
 from urh.signalprocessing.MessageType import MessageType
 from urh.signalprocessing.Modulator import Modulator
 from urh.signalprocessing.Participant import Participant
+from urh.signalprocessing.ProtocoLabel import ProtocolLabel
 from urh.signalprocessing.Signal import Signal
 from urh.util import util as urh_util
 from urh.util.Logger import logger
@@ -120,6 +119,10 @@ class ProtocolAnalyzer(object):
     def plain_ascii_str(self):
         return [msg.plain_ascii_str for msg in self.messages]
 
+    @property
+    def decoded_bits(self):
+        return [msg.decoded_bits for msg in self.messages]
+
     @property
     def decoded_proto_bits_str(self):
         """
@@ -223,7 +226,7 @@ class ProtocolAnalyzer(object):
         bit_len = signal.bit_len
 
         ppseq = signal_functions.grab_pulse_lens(signal.qad, signal.qad_center, signal.tolerance,
-                                                signal.modulation_type, signal.bit_len)
+                                                 signal.modulation_type, signal.bit_len)
 
         bit_data, pauses, bit_sample_pos = self._ppseq_to_bits(ppseq, bit_len, pause_threshold=signal.pause_threshold)
         if signal.message_length_divisor > 1 and signal.modulation_type_str == "ASK":
@@ -658,89 +661,15 @@ class ProtocolAnalyzer(object):
                     message.message_type = message_type
                     break
 
-    def auto_assign_participants(self, participants):
-        """
-
-        :type participants: list of Participant
-        :return:
-        """
-        if len(participants) == 0:
-            return
-
-        if len(participants) == 1:
-            for message in self.messages:
-                message.participant = participants[0]
-            return
-
-        # Try to assign participants based on SRC_ADDRESS label and participant address
-        for msg in filter(lambda m: m.participant is None, self.messages):
-            src_address = msg.get_src_address_from_data()
-            if src_address:
-                try:
-                    msg.participant = next(p for p in participants if p.address_hex == src_address)
-                except StopIteration:
-                    pass
-
-        # Assign remaining participants based on RSSI of messages
-        rssis = np.array([msg.rssi for msg in self.messages], dtype=np.float32)
-        min_rssi, max_rssi = util.minmax(rssis)
-        center_spacing = (max_rssi - min_rssi) / (len(participants) - 1)
-        centers = [min_rssi + i * center_spacing for i in range(0, len(participants))]
-        rssi_assigned_centers = []
-
-        for rssi in rssis:
-            center_index = np.argmin(np.abs(rssi - centers))
-            rssi_assigned_centers.append(int(center_index))
-
-        participants.sort(key=lambda participant: participant.relative_rssi)
-        for message, center_index in zip(self.messages, rssi_assigned_centers):
-            if message.participant is None:
-                message.participant = participants[center_index]
-
-    def auto_assign_participant_addresses(self, participants):
-        """
-
-        :type participants: list of Participant
-        :return:
-        """
-        participants_without_address = [p for p in participants if not p.address_hex]
-
-        if len(participants_without_address) == 0:
-            return
-
-        for msg in self.messages:
-            if msg.participant in participants_without_address:
-                src_address = msg.get_src_address_from_data()
-                if src_address:
-                    participants_without_address.remove(msg.participant)
-                    msg.participant.address_hex = src_address
-
-    def auto_assign_decodings(self, decodings):
-        """
-        :type decodings: list of Encoding
-        """
-        nrz_decodings = [decoding for decoding in decodings if decoding.is_nrz or decoding.is_nrzi]
-        fallback = nrz_decodings[0] if nrz_decodings else None
-        candidate_decodings = [decoding for decoding in decodings
-                               if decoding not in nrz_decodings and not decoding.contains_cut]
-
-        for message in self.messages:
-            decoder_found = False
-
-            for decoder in candidate_decodings:
-                if decoder.applies_for_message(message.plain_bits):
-                    message.decoder = decoder
-                    decoder_found = True
-                    break
-
-            if not decoder_found and fallback:
-                message.decoder = fallback
-
     def auto_assign_labels(self):
-        format_finder = FormatFinder(self)
+        from urh.awre.FormatFinder import FormatFinder
+        format_finder = FormatFinder(self.messages)
+        format_finder.run(max_iterations=10)
 
-        # OPEN: Perform multiple iterations with varying priorities later
-        format_finder.perform_iteration()
+        self.message_types[:] = format_finder.message_types
+        for msg_type, indices in format_finder.existing_message_types.items():
+            for i in indices:
+                self.messages[i].message_type = msg_type
 
     @staticmethod
     def get_protocol_from_string(message_strings: list, is_hex=None, default_pause=0, sample_rate=1e6):
